@@ -13,7 +13,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: main.py,v 1.135 2006/03/25 08:07:09 shy Exp $
+# $Id: main.py,v 1.136 2006/08/26 16:01:18 shy Exp $
 #
 
 import getopt
@@ -65,8 +65,7 @@ Options:
 '''
 
 def usage():
-    sys.stderr.write(USAGE)
-    sys.exit(1)
+    raise SystemExit, USAGE
 
 def _traceback(exception_type, value, tb):
     response_id = 1
@@ -103,7 +102,7 @@ def _traceback(exception_type, value, tb):
         else: # close button
             break
     dialog.destroy()
-    sys.exit(1)
+    raise SystemExit
 
 if 'DISPLAY' in os.environ:
     if 'gtk' in sys.modules:
@@ -117,8 +116,7 @@ def main():
     sys.stderr = os.fdopen(sys.stderr.fileno(), 'w')
     # check if X is running
     if 'DISPLAY' not in os.environ:
-        sys.stderr.write('Error: cannot open display (abort)\n')
-        sys.exit(1)
+        raise SystemExit, 'Error: cannot open display (abort)\n'
     # parse command line arguments
     try:
         options, rest = getopt.getopt(sys.argv[1:], 'H:U:R:ph',
@@ -173,27 +171,22 @@ def main():
         ninix.home.NINIX_USER = user_dir
     config = ninix.home.load_config()
     if config is None:
-        sys.stderr.write('Home directory not found (abort)\n')
-        sys.exit(1)
+        raise SystemExit, 'Home directory not found (abort)\n'
     # aquire Inter Process Mutex (not Global Mutex)
     lockfile = open(os.path.join(ninix.home.get_ninix_home(), '.lock'), 'w')
     try:
         fcntl.flock(lockfile, fcntl.LOCK_EX | fcntl.LOCK_NB)
     except:
-        print 'ninix-aya is already running'
-        sys.exit(1)
+        raise SystemExit, 'ninix-aya is already running'
     # check if at least one set of ghost, surface, and balloon
     ghosts, shells, balloons, plugins, nekoninni, katochan, kinoko = config ## FIXME
     if not ghosts:
-        sys.stderr.write('Error: no ghost found\n')
-        sys.exit(1)
+        raise SystemExit, 'Error: no ghost found\n'
     elif not shells and \
          not filter(lambda ghost: ghost[3], ghosts):
-        sys.stderr.write('Error: no shell found\n')
-        sys.exit(1)
+        raise SystemExit, 'Error: no shell found\n'
     elif not balloons:
-        sys.stderr.write('Error: no balloon found\n')
-        sys.exit(1)
+        raise SystemExit, 'Error: no balloon found\n'
     for desc, shiori_dir, use_makoto, surface_set, balloon, prefix, shiori_dll, shiori_name in ghosts:
         print 'ghost:', desc.get('name', '<none>').encode('utf-8', 'ignore')
         for name, surface_dir, surface_desc, surface_alias, surface in \
@@ -1071,8 +1064,7 @@ class Application:
             try:
                 os.execve(argv[0], argv, environ)
             except OSError:
-                sys.stderr.write('Error: %s failed (abort)\n' % argv[0])
-                os._exit(1)
+                raise SystemExit, 'Error: %s failed (abort)\n' % argv[0]
         self.plugin_pids.append(pid)
 
     def open_ghost_manager(self):
