@@ -120,8 +120,7 @@ class Catalog_xml:
         try:
             codecs.lookup(encoding)
         except:
-            sys.stderr.write('Unsupported encoding %s' % repr(encoding))
-            sys.exit(-1)
+            raise SystemExit, 'Unsupported encoding %s' % repr(encoding)
         nest = 0
         new_entry = {}
         set_id = None
