@@ -10,7 +10,7 @@
 #  PURPOSE.  See the GNU General Public License for more details.
 #
 
-NUMBER = '3.8.7'
+NUMBER = '3.8.9a'
 CODENAME = 'hacking run'
 
 VERSION = '%s (%s)' % (NUMBER, CODENAME)
